# Generated from uvl_python_parser.g4 by ANTLR 4.13.2
from antlr4 import *

if "." in __name__:
    from .uvl_python_parser import uvl_python_parser
else:
    from uvl_python_parser import uvl_python_parser


# This class defines a complete listener for a parse tree produced by uvl_python_parser.
class uvl_python_parserListener(ParseTreeListener):

    # Enter a parse tree produced by uvl_python_parser#featureModel.
    def enterFeatureModel(self, ctx: uvl_python_parser.FeatureModelContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#featureModel.
    def exitFeatureModel(self, ctx: uvl_python_parser.FeatureModelContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#includes.
    def enterIncludes(self, ctx: uvl_python_parser.IncludesContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#includes.
    def exitIncludes(self, ctx: uvl_python_parser.IncludesContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#includeLine.
    def enterIncludeLine(self, ctx: uvl_python_parser.IncludeLineContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#includeLine.
    def exitIncludeLine(self, ctx: uvl_python_parser.IncludeLineContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#namespace.
    def enterNamespace(self, ctx: uvl_python_parser.NamespaceContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#namespace.
    def exitNamespace(self, ctx: uvl_python_parser.NamespaceContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#imports.
    def enterImports(self, ctx: uvl_python_parser.ImportsContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#imports.
    def exitImports(self, ctx: uvl_python_parser.ImportsContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#importLine.
    def enterImportLine(self, ctx: uvl_python_parser.ImportLineContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#importLine.
    def exitImportLine(self, ctx: uvl_python_parser.ImportLineContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#features.
    def enterFeatures(self, ctx: uvl_python_parser.FeaturesContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#features.
    def exitFeatures(self, ctx: uvl_python_parser.FeaturesContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#OrGroup.
    def enterOrGroup(self, ctx: uvl_python_parser.OrGroupContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#OrGroup.
    def exitOrGroup(self, ctx: uvl_python_parser.OrGroupContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#AlternativeGroup.
    def enterAlternativeGroup(self, ctx: uvl_python_parser.AlternativeGroupContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#AlternativeGroup.
    def exitAlternativeGroup(self, ctx: uvl_python_parser.AlternativeGroupContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#OptionalGroup.
    def enterOptionalGroup(self, ctx: uvl_python_parser.OptionalGroupContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#OptionalGroup.
    def exitOptionalGroup(self, ctx: uvl_python_parser.OptionalGroupContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#MandatoryGroup.
    def enterMandatoryGroup(self, ctx: uvl_python_parser.MandatoryGroupContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#MandatoryGroup.
    def exitMandatoryGroup(self, ctx: uvl_python_parser.MandatoryGroupContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#CardinalityGroup.
    def enterCardinalityGroup(self, ctx: uvl_python_parser.CardinalityGroupContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#CardinalityGroup.
    def exitCardinalityGroup(self, ctx: uvl_python_parser.CardinalityGroupContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#groupSpec.
    def enterGroupSpec(self, ctx: uvl_python_parser.GroupSpecContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#groupSpec.
    def exitGroupSpec(self, ctx: uvl_python_parser.GroupSpecContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#feature.
    def enterFeature(self, ctx: uvl_python_parser.FeatureContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#feature.
    def exitFeature(self, ctx: uvl_python_parser.FeatureContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#featureCardinality.
    def enterFeatureCardinality(self, ctx: uvl_python_parser.FeatureCardinalityContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#featureCardinality.
    def exitFeatureCardinality(self, ctx: uvl_python_parser.FeatureCardinalityContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#attributes.
    def enterAttributes(self, ctx: uvl_python_parser.AttributesContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#attributes.
    def exitAttributes(self, ctx: uvl_python_parser.AttributesContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#attribute.
    def enterAttribute(self, ctx: uvl_python_parser.AttributeContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#attribute.
    def exitAttribute(self, ctx: uvl_python_parser.AttributeContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#valueAttribute.
    def enterValueAttribute(self, ctx: uvl_python_parser.ValueAttributeContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#valueAttribute.
    def exitValueAttribute(self, ctx: uvl_python_parser.ValueAttributeContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#key.
    def enterKey(self, ctx: uvl_python_parser.KeyContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#key.
    def exitKey(self, ctx: uvl_python_parser.KeyContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#value.
    def enterValue(self, ctx: uvl_python_parser.ValueContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#value.
    def exitValue(self, ctx: uvl_python_parser.ValueContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#vector.
    def enterVector(self, ctx: uvl_python_parser.VectorContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#vector.
    def exitVector(self, ctx: uvl_python_parser.VectorContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#SingleConstraintAttribute.
    def enterSingleConstraintAttribute(
        self, ctx: uvl_python_parser.SingleConstraintAttributeContext
    ):
        pass

    # Exit a parse tree produced by uvl_python_parser#SingleConstraintAttribute.
    def exitSingleConstraintAttribute(
        self, ctx: uvl_python_parser.SingleConstraintAttributeContext
    ):
        pass

    # Enter a parse tree produced by uvl_python_parser#ListConstraintAttribute.
    def enterListConstraintAttribute(
        self, ctx: uvl_python_parser.ListConstraintAttributeContext
    ):
        pass

    # Exit a parse tree produced by uvl_python_parser#ListConstraintAttribute.
    def exitListConstraintAttribute(
        self, ctx: uvl_python_parser.ListConstraintAttributeContext
    ):
        pass

    # Enter a parse tree produced by uvl_python_parser#constraintList.
    def enterConstraintList(self, ctx: uvl_python_parser.ConstraintListContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#constraintList.
    def exitConstraintList(self, ctx: uvl_python_parser.ConstraintListContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#constraints.
    def enterConstraints(self, ctx: uvl_python_parser.ConstraintsContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#constraints.
    def exitConstraints(self, ctx: uvl_python_parser.ConstraintsContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#constraintLine.
    def enterConstraintLine(self, ctx: uvl_python_parser.ConstraintLineContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#constraintLine.
    def exitConstraintLine(self, ctx: uvl_python_parser.ConstraintLineContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#OrConstraint.
    def enterOrConstraint(self, ctx: uvl_python_parser.OrConstraintContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#OrConstraint.
    def exitOrConstraint(self, ctx: uvl_python_parser.OrConstraintContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#EquationConstraint.
    def enterEquationConstraint(self, ctx: uvl_python_parser.EquationConstraintContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#EquationConstraint.
    def exitEquationConstraint(self, ctx: uvl_python_parser.EquationConstraintContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#LiteralConstraint.
    def enterLiteralConstraint(self, ctx: uvl_python_parser.LiteralConstraintContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#LiteralConstraint.
    def exitLiteralConstraint(self, ctx: uvl_python_parser.LiteralConstraintContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#ParenthesisConstraint.
    def enterParenthesisConstraint(
        self, ctx: uvl_python_parser.ParenthesisConstraintContext
    ):
        pass

    # Exit a parse tree produced by uvl_python_parser#ParenthesisConstraint.
    def exitParenthesisConstraint(
        self, ctx: uvl_python_parser.ParenthesisConstraintContext
    ):
        pass

    # Enter a parse tree produced by uvl_python_parser#NotConstraint.
    def enterNotConstraint(self, ctx: uvl_python_parser.NotConstraintContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#NotConstraint.
    def exitNotConstraint(self, ctx: uvl_python_parser.NotConstraintContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#AndConstraint.
    def enterAndConstraint(self, ctx: uvl_python_parser.AndConstraintContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#AndConstraint.
    def exitAndConstraint(self, ctx: uvl_python_parser.AndConstraintContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#EquivalenceConstraint.
    def enterEquivalenceConstraint(
        self, ctx: uvl_python_parser.EquivalenceConstraintContext
    ):
        pass

    # Exit a parse tree produced by uvl_python_parser#EquivalenceConstraint.
    def exitEquivalenceConstraint(
        self, ctx: uvl_python_parser.EquivalenceConstraintContext
    ):
        pass

    # Enter a parse tree produced by uvl_python_parser#ImplicationConstraint.
    def enterImplicationConstraint(
        self, ctx: uvl_python_parser.ImplicationConstraintContext
    ):
        pass

    # Exit a parse tree produced by uvl_python_parser#ImplicationConstraint.
    def exitImplicationConstraint(
        self, ctx: uvl_python_parser.ImplicationConstraintContext
    ):
        pass

    # Enter a parse tree produced by uvl_python_parser#EqualEquation.
    def enterEqualEquation(self, ctx: uvl_python_parser.EqualEquationContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#EqualEquation.
    def exitEqualEquation(self, ctx: uvl_python_parser.EqualEquationContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#LowerEquation.
    def enterLowerEquation(self, ctx: uvl_python_parser.LowerEquationContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#LowerEquation.
    def exitLowerEquation(self, ctx: uvl_python_parser.LowerEquationContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#GreaterEquation.
    def enterGreaterEquation(self, ctx: uvl_python_parser.GreaterEquationContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#GreaterEquation.
    def exitGreaterEquation(self, ctx: uvl_python_parser.GreaterEquationContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#LowerEqualsEquation.
    def enterLowerEqualsEquation(
        self, ctx: uvl_python_parser.LowerEqualsEquationContext
    ):
        pass

    # Exit a parse tree produced by uvl_python_parser#LowerEqualsEquation.
    def exitLowerEqualsEquation(
        self, ctx: uvl_python_parser.LowerEqualsEquationContext
    ):
        pass

    # Enter a parse tree produced by uvl_python_parser#GreaterEqualsEquation.
    def enterGreaterEqualsEquation(
        self, ctx: uvl_python_parser.GreaterEqualsEquationContext
    ):
        pass

    # Exit a parse tree produced by uvl_python_parser#GreaterEqualsEquation.
    def exitGreaterEqualsEquation(
        self, ctx: uvl_python_parser.GreaterEqualsEquationContext
    ):
        pass

    # Enter a parse tree produced by uvl_python_parser#NotEqualsEquation.
    def enterNotEqualsEquation(self, ctx: uvl_python_parser.NotEqualsEquationContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#NotEqualsEquation.
    def exitNotEqualsEquation(self, ctx: uvl_python_parser.NotEqualsEquationContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#expression.
    def enterExpression(self, ctx: uvl_python_parser.ExpressionContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#expression.
    def exitExpression(self, ctx: uvl_python_parser.ExpressionContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#MultiplicativeExpr.
    def enterMultiplicativeExpr(self, ctx: uvl_python_parser.MultiplicativeExprContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#MultiplicativeExpr.
    def exitMultiplicativeExpr(self, ctx: uvl_python_parser.MultiplicativeExprContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#AddExpression.
    def enterAddExpression(self, ctx: uvl_python_parser.AddExpressionContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#AddExpression.
    def exitAddExpression(self, ctx: uvl_python_parser.AddExpressionContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#SubExpression.
    def enterSubExpression(self, ctx: uvl_python_parser.SubExpressionContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#SubExpression.
    def exitSubExpression(self, ctx: uvl_python_parser.SubExpressionContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#PrimaryExpressionExpression.
    def enterPrimaryExpressionExpression(
        self, ctx: uvl_python_parser.PrimaryExpressionExpressionContext
    ):
        pass

    # Exit a parse tree produced by uvl_python_parser#PrimaryExpressionExpression.
    def exitPrimaryExpressionExpression(
        self, ctx: uvl_python_parser.PrimaryExpressionExpressionContext
    ):
        pass

    # Enter a parse tree produced by uvl_python_parser#DivExpression.
    def enterDivExpression(self, ctx: uvl_python_parser.DivExpressionContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#DivExpression.
    def exitDivExpression(self, ctx: uvl_python_parser.DivExpressionContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#MulExpression.
    def enterMulExpression(self, ctx: uvl_python_parser.MulExpressionContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#MulExpression.
    def exitMulExpression(self, ctx: uvl_python_parser.MulExpressionContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#FloatLiteralExpression.
    def enterFloatLiteralExpression(
        self, ctx: uvl_python_parser.FloatLiteralExpressionContext
    ):
        pass

    # Exit a parse tree produced by uvl_python_parser#FloatLiteralExpression.
    def exitFloatLiteralExpression(
        self, ctx: uvl_python_parser.FloatLiteralExpressionContext
    ):
        pass

    # Enter a parse tree produced by uvl_python_parser#IntegerLiteralExpression.
    def enterIntegerLiteralExpression(
        self, ctx: uvl_python_parser.IntegerLiteralExpressionContext
    ):
        pass

    # Exit a parse tree produced by uvl_python_parser#IntegerLiteralExpression.
    def exitIntegerLiteralExpression(
        self, ctx: uvl_python_parser.IntegerLiteralExpressionContext
    ):
        pass

    # Enter a parse tree produced by uvl_python_parser#StringLiteralExpression.
    def enterStringLiteralExpression(
        self, ctx: uvl_python_parser.StringLiteralExpressionContext
    ):
        pass

    # Exit a parse tree produced by uvl_python_parser#StringLiteralExpression.
    def exitStringLiteralExpression(
        self, ctx: uvl_python_parser.StringLiteralExpressionContext
    ):
        pass

    # Enter a parse tree produced by uvl_python_parser#AggregateFunctionExpression.
    def enterAggregateFunctionExpression(
        self, ctx: uvl_python_parser.AggregateFunctionExpressionContext
    ):
        pass

    # Exit a parse tree produced by uvl_python_parser#AggregateFunctionExpression.
    def exitAggregateFunctionExpression(
        self, ctx: uvl_python_parser.AggregateFunctionExpressionContext
    ):
        pass

    # Enter a parse tree produced by uvl_python_parser#LiteralExpression.
    def enterLiteralExpression(self, ctx: uvl_python_parser.LiteralExpressionContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#LiteralExpression.
    def exitLiteralExpression(self, ctx: uvl_python_parser.LiteralExpressionContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#BracketExpression.
    def enterBracketExpression(self, ctx: uvl_python_parser.BracketExpressionContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#BracketExpression.
    def exitBracketExpression(self, ctx: uvl_python_parser.BracketExpressionContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#SumAggregateFunctionExpression.
    def enterSumAggregateFunctionExpression(
        self, ctx: uvl_python_parser.SumAggregateFunctionExpressionContext
    ):
        pass

    # Exit a parse tree produced by uvl_python_parser#SumAggregateFunctionExpression.
    def exitSumAggregateFunctionExpression(
        self, ctx: uvl_python_parser.SumAggregateFunctionExpressionContext
    ):
        pass

    # Enter a parse tree produced by uvl_python_parser#AvgAggregateFunctionExpression.
    def enterAvgAggregateFunctionExpression(
        self, ctx: uvl_python_parser.AvgAggregateFunctionExpressionContext
    ):
        pass

    # Exit a parse tree produced by uvl_python_parser#AvgAggregateFunctionExpression.
    def exitAvgAggregateFunctionExpression(
        self, ctx: uvl_python_parser.AvgAggregateFunctionExpressionContext
    ):
        pass

    # Enter a parse tree produced by uvl_python_parser#StringAggregateFunctionExpression.
    def enterStringAggregateFunctionExpression(
        self, ctx: uvl_python_parser.StringAggregateFunctionExpressionContext
    ):
        pass

    # Exit a parse tree produced by uvl_python_parser#StringAggregateFunctionExpression.
    def exitStringAggregateFunctionExpression(
        self, ctx: uvl_python_parser.StringAggregateFunctionExpressionContext
    ):
        pass

    # Enter a parse tree produced by uvl_python_parser#NumericAggregateFunctionExpression.
    def enterNumericAggregateFunctionExpression(
        self, ctx: uvl_python_parser.NumericAggregateFunctionExpressionContext
    ):
        pass

    # Exit a parse tree produced by uvl_python_parser#NumericAggregateFunctionExpression.
    def exitNumericAggregateFunctionExpression(
        self, ctx: uvl_python_parser.NumericAggregateFunctionExpressionContext
    ):
        pass

    # Enter a parse tree produced by uvl_python_parser#sumAggregateFunction.
    def enterSumAggregateFunction(
        self, ctx: uvl_python_parser.SumAggregateFunctionContext
    ):
        pass

    # Exit a parse tree produced by uvl_python_parser#sumAggregateFunction.
    def exitSumAggregateFunction(
        self, ctx: uvl_python_parser.SumAggregateFunctionContext
    ):
        pass

    # Enter a parse tree produced by uvl_python_parser#avgAggregateFunction.
    def enterAvgAggregateFunction(
        self, ctx: uvl_python_parser.AvgAggregateFunctionContext
    ):
        pass

    # Exit a parse tree produced by uvl_python_parser#avgAggregateFunction.
    def exitAvgAggregateFunction(
        self, ctx: uvl_python_parser.AvgAggregateFunctionContext
    ):
        pass

    # Enter a parse tree produced by uvl_python_parser#LengthAggregateFunction.
    def enterLengthAggregateFunction(
        self, ctx: uvl_python_parser.LengthAggregateFunctionContext
    ):
        pass

    # Exit a parse tree produced by uvl_python_parser#LengthAggregateFunction.
    def exitLengthAggregateFunction(
        self, ctx: uvl_python_parser.LengthAggregateFunctionContext
    ):
        pass

    # Enter a parse tree produced by uvl_python_parser#FloorAggregateFunction.
    def enterFloorAggregateFunction(
        self, ctx: uvl_python_parser.FloorAggregateFunctionContext
    ):
        pass

    # Exit a parse tree produced by uvl_python_parser#FloorAggregateFunction.
    def exitFloorAggregateFunction(
        self, ctx: uvl_python_parser.FloorAggregateFunctionContext
    ):
        pass

    # Enter a parse tree produced by uvl_python_parser#CeilAggregateFunction.
    def enterCeilAggregateFunction(
        self, ctx: uvl_python_parser.CeilAggregateFunctionContext
    ):
        pass

    # Exit a parse tree produced by uvl_python_parser#CeilAggregateFunction.
    def exitCeilAggregateFunction(
        self, ctx: uvl_python_parser.CeilAggregateFunctionContext
    ):
        pass

    # Enter a parse tree produced by uvl_python_parser#reference.
    def enterReference(self, ctx: uvl_python_parser.ReferenceContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#reference.
    def exitReference(self, ctx: uvl_python_parser.ReferenceContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#id.
    def enterId(self, ctx: uvl_python_parser.IdContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#id.
    def exitId(self, ctx: uvl_python_parser.IdContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#featureType.
    def enterFeatureType(self, ctx: uvl_python_parser.FeatureTypeContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#featureType.
    def exitFeatureType(self, ctx: uvl_python_parser.FeatureTypeContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#languageLevel.
    def enterLanguageLevel(self, ctx: uvl_python_parser.LanguageLevelContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#languageLevel.
    def exitLanguageLevel(self, ctx: uvl_python_parser.LanguageLevelContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#majorLevel.
    def enterMajorLevel(self, ctx: uvl_python_parser.MajorLevelContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#majorLevel.
    def exitMajorLevel(self, ctx: uvl_python_parser.MajorLevelContext):
        pass

    # Enter a parse tree produced by uvl_python_parser#minorLevel.
    def enterMinorLevel(self, ctx: uvl_python_parser.MinorLevelContext):
        pass

    # Exit a parse tree produced by uvl_python_parser#minorLevel.
    def exitMinorLevel(self, ctx: uvl_python_parser.MinorLevelContext):
        pass


del uvl_python_parser
